@@ -1,7 +1,9 @@
 $:.unshift(File.dirname(__FILE__) + "/../lib/")
+require 'rubygems'
+require 'bundler/setup'
+
 require 'riot'
 Riot.verbose
-
 Riot.pretty_dots if ENV["TM_MODE"]
 
 module Riot
